summaryrefslogtreecommitdiff
path: root/cloudinit
diff options
context:
space:
mode:
authorRyan Harper <ryan.harper@canonical.com>2020-04-30 09:24:42 -0500
committerGitHub <noreply@github.com>2020-04-30 10:24:42 -0400
commit5815dd9bb859859573d9d3219918e5ab1ce3d3af (patch)
treee4559ae30a09341ba97650e89811b820d3447eed /cloudinit
parent03aed95829ce52214a6a888d6bd1a5d841e85464 (diff)
downloadvyos-cloud-init-5815dd9bb859859573d9d3219918e5ab1ce3d3af.tar.gz
vyos-cloud-init-5815dd9bb859859573d9d3219918e5ab1ce3d3af.zip
yum_add_repo: Add Centos to the supported distro list (#340)
Users of Centos who want to add yum repos, like they do on Fedora or RHEL get this unfortunate message: Skipping modules 'yum-add-repo' because they are not verified on distro 'centos'. To run anyway, add them to 'unverified_modules' in config Centos certainly supports yum, add it to the supported distro list in the module.
Diffstat (limited to 'cloudinit')
-rw-r--r--cloudinit/config/cc_yum_add_repo.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/cloudinit/config/cc_yum_add_repo.py b/cloudinit/config/cc_yum_add_repo.py
index 3673166a..01fe683c 100644
--- a/cloudinit/config/cc_yum_add_repo.py
+++ b/cloudinit/config/cc_yum_add_repo.py
@@ -18,7 +18,7 @@ entry, the config entry will be skipped.
**Module frequency:** per always
**Supported distros:** fedora, rhel
**Config keys**::
@@ -36,7 +36,7 @@ from configparser import ConfigParser
from cloudinit import util
-distros = ['fedora', 'rhel']
+distros = ['centos', 'fedora', 'rhel']
def _canonicalize_id(repo_id):
@@ -18,7 +18,7 @@ entry, the config entry will be skipped.
**Module frequency:** per always
-**Supported distros:** fedora, rhel
+**Supported distros:** centos, fedora, rhel
**Config keys**::